@@ -13,7 +13,6 @@ class BzttExcl:  #工单处理
     wb = {}
     # def __init__(self, system_info, oltInfo, soft_ware_info):
     def  __init__(self,system_info={}):
-        print("构造")
         log_lv_data = {
             "ALL": 0,
             "TRACE": 1,
@@ -26,6 +25,10 @@ class BzttExcl:  #工单处理
         }
         log_level = system_info.get("log_level","INFO")
         self.log_lv = log_lv_data[log_level]
+        print_data = [
+            {"text": "类构造成功", "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
 
         #self.app=xw.App(visible=True,add_book=False)
     def __del__(self):
@@ -41,11 +44,29 @@ class BzttExcl:  #工单处理
             self.wb[wdInfo].close()
         self.app.quit()
         '''
+    # 显示信息
+    def print_log(self, log_lv_info, log_lv_num):
+        log_lv_data = {
+            "ALL": 0,
+            "TRACE": 1,
+            "DEBUG": 2,
+            "INFO": 3,
+            "WARN": 4,
+            "ERROR": 5,
+            "FATAL": 6,
+            "OFF": 7,
+        }
+        log_lv = log_lv_data[log_lv_num.upper()]
+       
+        if log_lv >= self.log_lv:
+            print("\033[1;%sm%s\033[0m" % ("34", log_lv_num.upper()), end=" - ")
+            for info in log_lv_info:
+                info.setdefault("end", "\n")
+                print("\033[1;%sm%s\033[0m" % (info["color"], info["text"]), end=info["end"])
+    # excel 判断表格内容（ifs）
     def ifsData(self,jsonData):
-        print("ifsInfo",jsonData)
         screen = "=IFS("
         for conditionInfo in jsonData["condition"]:
-            
             if conditionInfo["type"] == "exist":
                 #print("exist",conditionInfo)
                 screenInfo = "OR(COUNTIF('[%s]%s'!%s,{" % (conditionInfo["sourceFile"],conditionInfo["sourceShell"],conditionInfo["Range"])
@@ -61,29 +82,55 @@ class BzttExcl:  #工单处理
                 screenInfo = "1,\"%s\","%(conditionInfo["targetData"])
                 screen = screen + screenInfo
         screen = screen[:-1] + ")" 
-        print("screen_debug",screen)
-        
+        # print("screen_debug",screen)
+
         sht = self.wb[jsonData["sourceTitle"]].sheets(jsonData["sourceShell"])
         info = sht.used_range
         nrows = info.last_cell.row
         ncolumns = info.last_cell.column
-        print("nrows",nrows,"ncolumns",ncolumns)
-        print("正在计算请稍后...")
-        sht.range(jsonData["startRangeCol"] + jsonData["startRangeRow"]).value = screen
+        # print("nrows",nrows,"ncolumns",ncolumns)
 
+        # print("正在计算请稍后...")
+        sht.range(jsonData["startRangeCol"] + jsonData["startRangeRow"]).value = screen
         rangeEndStr = jsonData["startRangeCol"] + str(nrows)
-        #print("start",jsonData["startRange"],"end",jsonData["startRange"] + ':' + rangeEndStr)
         sourceRange = sht.range(jsonData["startRangeCol"] + jsonData["startRangeRow"]).api
         fillRange = sht.range(jsonData["startRangeCol"] + jsonData["startRangeRow"] + ':' + rangeEndStr).api
+        
+        print_data = [
+            {"text": "计算公式：" + screen, "color": "34"},
+
+        ]
+        self.print_log(print_data, "DEBUG")
+
+        print_data = [
+            {"text": "判断函数（ifs）", "color": "33"},
+            {"text": "操作表格： [%s]%s!%s%s:%s" % (jsonData["sourceTitle"],jsonData["sourceShell"],jsonData["startRangeCol"],jsonData["startRangeRow"],rangeEndStr ), "color": "34"},
+            {"text": "正在计算中，请稍后...", "color": "33"}
+
+        ]
+        self.print_log(print_data, "INFO")
         sourceRange.AutoFill(fillRange, 0)
 
+    # 新建Shell
     def addShell(self,jsonData):
-        print("新建Shell",jsonData)
+        # print("新建Shell",jsonData)
+        print_data = [
+            {"text": "新建Shell,请稍后...", "color": "33"},
+            {"text": "[%s]%s,{%s}" % (jsonData["sourceTitle"],jsonData["after"],jsonData["targetShell"]), "color": "33"}
 
+        ]
+        self.print_log(print_data, "INFO")
         sht =  self.wb[jsonData["sourceTitle"]].sheets.add(jsonData["targetShell"], after=jsonData["after"])
-
+    
+    # 筛选数据，计算数量，列
     def countyCountyNum(self,jsonData):
-        print("配置数据",jsonData)
+        #print("jsonData",jsonData)
+        print_data = [
+            {"text": "正在筛选数据，计算数量，请稍后...", "color": "33"}
+
+        ]
+        self.print_log(print_data, "INFO")
+
         #生成专用  =SUM(COUNTIFS(
         screen = "=SUM(COUNTIFS("
         for conditionInfo in jsonData["condition"]:
@@ -94,7 +141,7 @@ class BzttExcl:  #工单处理
                 screen = screen +screenInfo[:-1] + "}," 
             elif conditionInfo["type"] == "timeRange":
                
-                print("conditionInfo",conditionInfo["data"])
+                # print("conditionInfo",conditionInfo["data"])
                 #if conditionInfo["data"]["start"]["disable"] == "false": #处理开始
 
                 for timeInfo in conditionInfo["data"]:
@@ -115,6 +162,7 @@ class BzttExcl:  #工单处理
         #print("screen",screen)
  
         data = {}
+        log_data_tmp = ""
         #生成
         for info in jsonData["county"]:
             #print("countyCountyNum",info)
@@ -127,9 +175,23 @@ class BzttExcl:  #工单处理
                 #print("screenInfo",screenInfo)
                 
             data[info["title"]] = screen + screenInfoFor[:-1] + "))" 
-        #for info in data:
-        #    print(info,data[info])
+            log_data_tmp = log_data_tmp + info["title"] + " : " + screen + screenInfoFor[:-1] + "))" + "\n\n"
         
+        print_data = [
+            {"text": "筛选表格", "color": "33","end":"："},
+            {"text": "[%s]%s" % (jsonData["targetTitle"],jsonData["targetShell"]), "color": "34","end":"\n"},
+
+            {"text": "写入起始位置", "color": "33","end":"\n"},
+            {"text": "[%s]%s!%s%s" % (jsonData["targetTitle"],jsonData["targetShell"],jsonData["targetRange"]["startLetter"],jsonData["targetRange"]["startNum"]), "color": "34"},
+
+        ]
+        self.print_log(print_data, "INFO")
+
+        print_data = [
+            {"text": "筛选条件", "color": "33","end":"\n"},
+            {"text": log_data_tmp, "color": "34"},
+        ]
+        self.print_log(print_data, "DEBUG")
 
         i = int(jsonData["targetRange"]["startNum"])
         sht = self.wb[jsonData["targetTitle"]].sheets(jsonData["targetShell"])
@@ -137,40 +199,39 @@ class BzttExcl:  #工单处理
         for info in data:
             rang = jsonData["targetRange"]["startLetter"]+ str(i)
             sht.range(rang).formula = data[info]#单元格赋值
-            #sht.range( rang).api.NumberFormat = "0"  #单元格赋值
-            
-
-
-            #print("formula",str(dataValue))
-            #dataValue = sht.range(rang).formula #读取工作表中的数据
-            #sht.range( rang).value = str(dataValue) #将要读取的数据写入工作表
-
-
             i = i +1
 
         return
 
-        sht = self.wb["解决"].sheets[0]
-        sht.range('A4').formula = "=1"#单元格赋值
-        print(1)
-        sht.range('A2').formula = data["滨城区"]#单元格赋值
-
-
-    openfileNameApp = {
-        "":""
-    }
     def RemoveDuplicates(self,jsonData):
-        print("删除重复项",jsonData)
+
+        print_str_copy = "[%s]%s!%s:%s,{%s}" % (jsonData["sourceTitle"],jsonData["sourceShell"],jsonData["sourceRange"]["start"],jsonData["sourceRange"]["end"],jsonData["RemoveNum"])
+        print_data = [
+            {"text": "删除重复项", "color": "33"},
+            {"text": print_str_copy, "color": "33"},
+
+        ]
+        self.print_log(print_data, "INFO")
+
         shtSource = self.wb[jsonData["sourceTitle"]].sheets(jsonData["sourceShell"])
 
         shtSource.range(jsonData["sourceRange"]["start"],jsonData["sourceRange"]["end"]).api.RemoveDuplicates(int(jsonData["RemoveNum"]))
 
-
+    # 复制数据
     def copyData(self,copyJson):
-        print("复制数据:",copyJson)
+        print_str_copy = "[%s]%s!%s" % (copyJson["sourceTitle"],copyJson["sourceShell"],copyJson["sourceRange"]["start"] + ":" + copyJson["sourceRange"]["end"])
+        
+        print_str_paste = "[%s]%s!{ " % (copyJson["targetTitle"],copyJson["targetShell"])
+        for info in copyJson["targetRange"]:
+            print_str_paste = print_str_paste + info["start"] + ", "
+        print_str_paste = print_str_paste[:-1] + "}"
 
-        #print("sourceTitle",copyJson["sourceTitle"])
-        #print("targetTitle",copyJson["targetTitle"])
+        print_data = [
+            {"text": "复制数据", "color": "33"},
+            {"text": print_str_copy, "color": "33","end":" --> "},
+            {"text": print_str_paste, "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
 
         shtSource = self.wb[copyJson["sourceTitle"]].sheets(copyJson["sourceShell"])
         shtTarget = self.wb[copyJson["targetTitle"]].sheets(copyJson["targetShell"])
@@ -178,10 +239,10 @@ class BzttExcl:  #工单处理
         shtSource.range(rangSource).copy(destination=None)
 
         for pasteInfo in copyJson["targetRange"]:
-
             rangTarget = pasteInfo["start"]
             shtTarget.range(rangTarget).paste(paste="values_and_number_formats")
 
+
         '''
         copyDataTmp = shtSource.range(rangSource).value
         print("copyDataTmp",copyDataTmp)
@@ -189,6 +250,7 @@ class BzttExcl:  #工单处理
         #sht.range('A1').options(transpose=True).value=[1,2,3]
         shtTarget.range(rangTarget).options(transpose=True).value = copyDataTmp
         '''
+
     def ExcelColumn(self,n:int)->str:
         num = [chr(i) for i in range(65,91)]
         ret,(n,m) = '',divmod(n-1,26)
@@ -252,18 +314,29 @@ class BzttExcl:  #工单处理
 
         shtTarget.range(advancedFilterJson["targetRange"]).value = range_value_list
         self.wb[advancedFilterJson["targetTitle"]].save()
+
+    # 格式化数据（初始）
     def formatJson(self,formatJson):
+        print_data = [
+            {"text": "开始格式化数据", "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
 
         formatJsonStr =json.dumps(formatJson,ensure_ascii=False)   #转换字符串
         
-        #for info in formatJson["formatVariable"]:
-        
         for i in range(0,len(formatJson["formatVariable"])):
             formatJsonStr =json.dumps(formatJson,ensure_ascii=False)   #转换字符串
             fucInfoJson = formatJson["formatVariable"]
             info = fucInfoJson[i]
-            
-            
+
+            print_data = [
+                {"text": "格式化类型：", "color": "34","end":" "},
+                {"text": info["type"] , "color": "33"},
+
+                {"text": "格式化数据：", "color": "33","end":" "},
+                {"text": info, "color": "34"},
+            ]
+            self.print_log(print_data, "DEBUG")
 
             if info["type"] == "input":
                 inputIntStr = input(info["title"])
@@ -278,22 +351,20 @@ class BzttExcl:  #工单处理
                 #print("formatJsonStr:",formatJsonStr)
             elif info["type"] == "time":
                 startTimeStr = str(info["value"])
-                print("strptime",startTimeStr,info)
                 SourceTimeStr = datetime.datetime.strptime(startTimeStr,info["valueFormat"])  + datetime.timedelta(days = int(info["num"]))
                 startTimeStr = SourceTimeStr.strftime( info["format"] )   #'>%Y-%m-%d %H:%M:%S'
-
                 formatJsonStr = formatJsonStr.replace( "\"" + info["name"] + "\"",startTimeStr)
-                print("数据日期")
+
             elif info["type"] == "date2Rang":
-                print("date2Rang:",info["value"])
+                #print("date2Rang:",info["value"])
                 #str转time
                 SourceTimeStr = datetime.datetime.strptime(str(info["value"]["dateStr"]),info["value"]["dateFormat"])
                 year = SourceTimeStr.year
                 month = SourceTimeStr.month
                 day = SourceTimeStr.day
-                print("SourceTimeStr",SourceTimeStr,year,month,day)
+                #print("SourceTimeStr",SourceTimeStr,year,month,day)
                 for RangeFormatInfo in info["value"]["RangeFormat"]:
-                    print("RangeFormatInfo",RangeFormatInfo)
+                    #print("RangeFormatInfo",RangeFormatInfo)
                     chengeStr = 0
                     #输出B1
                     if RangeFormatInfo["type"] == "day":
@@ -313,7 +384,7 @@ class BzttExcl:  #工单处理
                             columnTial = columnInitial + chengeStr
                             columnStr = self.ExcelColumn(columnTial - RangeFormatInfo["Range"][0])
                             chengeAll = columnStr +  RangeFormatInfo["rowInitial"]
-                            print("chengeAll",chengeAll)
+                            #print("chengeAll",chengeAll)
                             formatJsonStr = formatJsonStr.replace(info["name"],chengeAll)
                             break
 
@@ -392,24 +463,51 @@ class BzttExcl:  #工单处理
 
         shtTarget.range(advancedFilterJson["targetRange"]).value = range_value_list
 
-    def openfile(self,iniFile):
-        print("初始化文件",iniFile)
+    def openfile(self,iniFile):        
+        print_data = [
+            {"text": "正在复制文件，请稍后...", "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
+
         #检测文件是否存在
 
         #复制文件,并重命名
         for fileInfo in iniFile["info"]:
-            print("复制文件:",fileInfo)
+            print_data = [
+                {"text": fileInfo["sourcePath"] + fileInfo["name"] + "." + fileInfo["suffix"], "color": "33","end":" --> "},
+                {"text": fileInfo["targetPath"] + fileInfo["name"] + "_" + fileInfo["title"] + "." + fileInfo["suffix"], "color": "33"},
+            ]
+            self.print_log(print_data, "INFO")
+
             shutil.copyfile(fileInfo["sourcePath"] + fileInfo["name"] + "." + fileInfo["suffix"], fileInfo["targetPath"] + fileInfo["name"] + "_" + fileInfo["title"] + "." + fileInfo["suffix"])
-        print("正在打开文件,请稍后...")
+        print_data = [
+            {"text": "文件复制完毕", "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
+
+        print_data = [
+                {"text": "正在打开文件,请稍后...", "color": "33"},
+        ]
+        self.print_log(print_data, "INFO")
+
         self.app = xw.App(visible=True,add_book=False)
         self.app.display_alerts=False
         
         #打开文件
         for fileInfo in iniFile["info"]:
-            print("打开文件:",fileInfo)
+            print_data = [
+                {"text": fileInfo["title"], "color": "33","end":" - "},
+                {"text": fileInfo["targetPath"] + fileInfo["name"] + "_" + fileInfo["title"] + "." + fileInfo["suffix"], "color": "33"},
+
+            ]
+            self.print_log(print_data, "INFO")
+
             #self.wb[fileInfo["title"]] =  xw.Book(fileInfo["path"] + fileInfo["name"] + "_" + fileInfo["title"] + "." + fileInfo["suffix"]) #创建一个新的Excel文件
             self.wb[fileInfo["title"]] =  self.app.books.open(fileInfo["targetPath"] + fileInfo["name"] + "_" + fileInfo["title"] + "." + fileInfo["suffix"]) #创建一个新的Excel文件
-
+        print_data = [
+            {"text": "文件打开完毕", "color": "33"}
+        ]
+        self.print_log(print_data, "INFO")
         #校验 文件
         
 
